rm(list=ls())

# Simple demonstration of coupling an optimiser to apsim. 
#setwd("/home/uqpdevo1/work/Software/Optimiser Demo 2018/R")

# We use the xml library to read / write .apsim files
library(XML)

# Helper function to read apsim output files
trim <- function (x) gsub("^\\s+|\\s+$", "", x)
read.apsim <- function (filename) {
  fp <- file(filename, "r")
  on.exit(close(fp))
  hdr<-readLines(fp, n=4)
  names<-unlist(strsplit(trim(hdr[3]), " +"))
  return(read.table(fp, skip = 0, col.names=names, row.names=NULL, na.strings=c("*", "?")))
}

# Read observed data
#  data from http://howleaky.net/images/greenmount%20min%20till.txt
obs<- read.csv("greenmount min till.txt", skip=27, header=T)
obs$Date<-as.Date(obs$Date, format="%d/%m/%Y")
obs$runoff <- obs$Runoff_mm_ZT

# Function to read apsim output and return a merged data frame of
# predictions & observations
readIt<-function(filename) {
   pred<- read.apsim(filename)
   pred$Date<-as.Date(pred$Date, format="%d/%m/%Y")

   df<-merge(pred[,c("Date", "runoff")], 
             obs[,c("Date", "runoff")], 
             by="Date", suffixes = c(".pred",".obs"),  all.x = T)
   df$month<- as.numeric(format.Date(df$Date, "%m"))
   df$year<- as.numeric(format.Date(df$Date, "%Y"))
   df$waterYear<-ifelse(df$month >= 11, df$year + 1, df$year)
   
   df2<-aggregate(df[,c("runoff.pred" , "runoff.obs")], 
                    list(df$waterYear), sum, na.rm=T)
   return(df2[df2$runoff.obs > 0,])
}

mae<- function(a, b) {
  return(sum(abs(a - b)) / length(a))
}

rmsd <- function(a, b) {
  e2<-(a - b) * (a - b)
  rmsdv <- sqrt(sum(e2)/length(e2))
  return(rmsdv)
}

# Calculate an error statistic of annual runoff
calcIt<-function(filename) {
   df <- readIt(filename)
   #return(rmsd(df$runoff.obs, df$runoff.pred))
   return(mae(df$runoff.obs, df$runoff.pred))
}


# Write a temporary apsim file, run it, and return an error statistic
doit<- function(cn2) {
   # Read the template .apsim file
   doc <- xmlTreeParse("Wheat_greenmount.apsim", useInternalNodes=T)

   # Set the parameter to be optimised
   for (x in getNodeSet(doc, "//CN2Bare")) {
      xmlValue(x) <- cn2
   }

   # Write out the file for apsim
   saveXML(doc, file="Temp.apsim")
  
   # Make sure there is no chance of reading stale output
   file.remove("Wheat_greenmount.out")
   
   # Run apsim
   system2("/home/uqpdevo1/apsim/Model/Apsim.exe",
          "Temp.apsim", stdout = F, stderr = F)
   
   errorStatistic <- calcIt("Wheat_greenmount.out")
   cat(cn2," = ", errorStatistic, "\n")
   
   return( errorStatistic )
}

# run the optimiser with an initial guess of 74
optim(74, doit, method="L-BFGS-B", lower=50, upper=98, 
      control=c(ndeps=0.5, maxit=25, factr=0.1))

