ptf @
<folder version="37" creator="Apsim 7.10-r4176" name="simulations">
  <simulation name="Wheat_greenmount">
    <metfile name="met">
      <filename name="filename" input="yes">../greenmount.met</filename>
    </metfile>
    <clock>
      <start_date type="date" description="Enter the start date of the simulation">01/01/1978</start_date>
      <end_date type="date" description="Enter the end date of the simulation">31/12/1991</end_date>
    </clock>
    <summaryfile />
    <area name="paddock">
      <surfaceom name="SurfaceOrganicMatter">
        <PoolName type="text" description="Organic Matter pool name">wheat</PoolName>
        <type type="list" listvalues="bambatsi,barley,base_type,broccoli,camaldulensis,canola,centro,chickpea,chikenmanure_base,cm,cmA,cmB,constants,cotton,cowpea,danthonia,fababean,fieldpea,fym,gbean,globulus,goatmanure,grandis,grass,horsegram,inert,lablab,lentil,lucerne,lupin,maize,manB,manure,medic,millet,mucuna,nativepasture,navybean,oats,orobanche,peanut,pigeonpea,potato,rice,sorghum,soybean,stylo,sugar,sunflower,sweetcorn,sweetsorghum,tillage,tithonia,vetch,weed,wheat" description="Organic Matter type">wheat</type>
        <mass type="text" description="Initial surface residue (kg/ha)">1000</mass>
        <cnr type="text" description="C:N ratio of initial residue">80</cnr>
        <standing_fraction type="text" description="Fraction of residue standing">0</standing_fraction>
      </surfaceom>
      <fertiliser />
      <wheat />
      <folder name="Manager folder">
        <manager2 name="Crop Management">
          <ui>
            <category type="category" description="Crop properties" />
            <crop type="crop" description="Name of this crop">wheat</crop>
            <category type="category" description="Sowing criteria" />
            <date1 type="ddmmmdate" description="Enter sowing window START date (dd-mmm)">01-jun</date1>
            <date3 type="ddmmmdate" description="Enter cultivar change date (na if not in use)">na</date3>
            <date2 type="ddmmmdate" description="Enter sowing window END date (dd-mmm)">10-jul</date2>
            <must_sow type="yesno" description="Must Sow">yes</must_sow>
            <rain_amount type="text" description="Enter amount of cumulative rainfall (mm)">25</rain_amount>
            <rain_days type="text" description="Enter number of days to accumulate rainfall (days)">7</rain_days>
            <esw_amount type="text" description="Enter amount of soil water (mm)">100</esw_amount>
            <category type="category" description="Sowing Parameters" />
            <cultivar1 type="cultivars" description="Enter cultivar : ">hartog</cultivar1>
            <cultivar2 type="cultivars" description="Enter 2nd Cultivar (na if not using a second cultivar)">na</cultivar2>
            <density1 type="text" description="Enter sowing density  (plants/m2)">100</density1>
            <depth1 type="text" description="Enter sowing depth  (mm)">30</depth1>
            <row_spacing1 type="text" description="Enter row spacing  (mm)">250</row_spacing1>
            <category type="category" description="Extra Parameters" />
            <ftn1 type="text" description="Enter Fertile Tiller Number (na for auto) : ">na</ftn1>
            <skiprow1 type="list" listvalues="solid, single, double" description="Skip row : ">solid</skiprow1>
            <tillageImplement type="text" description="Name of tillage implement (na if not in use): ">na</tillageImplement>
          </ui>
          <text>using System;
using ModelFramework;
using CSGeneral;

// Basic crop management: sowing &amp; harvesting.
// Multi-paddock aware.
// This component DOES NOT require a trigger from the sequencer.
// It will assume it is the only crop in the system if it doesnt find a sequencer.
// If it does find a sequencer, it will do nothing until told to (via Enter/Leave).
public class Script 
{      
   [Link()]  public Simulation MySimulation;
   
   [Param()] private string crop;         // The module name of this crop
   [Param()] private string date1;         //Start of sowing window
   [Param()] private string date2;         //End of sowing window
   [Param()] private string date3;         //date to change to different cultivar
   [Param()] int esw_amount;
   [Param()] private string must_sow;

   [Input()] private DateTime today;

   // Rainfall accumulator
   [Param()] int rain_days;              //check for rain over this period
   [Param()] int rain_amount;            //this much rain over that period

   // Daily rainfall from the system
   [Input] private double rain;
   private ManagerUtility.Tracker&lt;double&gt; rainTracker; 

   private bool inWindow = false;
   private bool endOfWindow = false;
   private bool ChangeCultivar = false;

   //initialise tracker, telling it how many days to track
   [EventHandler] public void OnInitialised()
   {
      rainTracker = new ManagerUtility.Tracker&lt;double&gt;(rain_days); 
   }

   // Daily tests common to all paddocks
   [EventHandler] public void OnPrepare()
   {
      bool startOfWindow = DateUtility.DatesEqual(date1, today);

      inWindow = DateUtility.WithinDates(date1, today, date2);
      ChangeCultivar = false;
      if(date3 != "na")  
         ChangeCultivar = DateUtility.WithinDates(date3, today, date2);
      endOfWindow = DateUtility.DatesEqual(date2, today);

      rainTracker.Add(rain);
      string currentPaddock = "";
      if (MySimulation.Get("currentPaddock", out currentPaddock) == false) 
      {
         // If there is no sequencer plugged in then we are it..
         if (canEnter &gt; 0) {
            OnEnter();
         }
         if (canLeave &gt; 0) {
            OnLeave();
         }
      }
   }
   // Test whether we can sow a crop today
   // +ve number - yes
   // 0          - no
   // -ve number - no, out of scope (planting window)
   [Output, Description("Test whether we can sow a crop today")] public int canEnter  {
      get {
         bool isPossibleToday = false;
         
         string currentPaddock;
         MySimulation.Get("currentPaddock", out currentPaddock);
         //Console.WriteLine("1. '" + currentPaddock + "'");

         Component paddockModule;
         if (currentPaddock != "")
            paddockModule = (Component) MySimulation.LinkByName(currentPaddock);
         else
            paddockModule = (Component) MySimulation.ChildPaddocks[0];
         //Console.WriteLine("2. " + paddockModule.Name);

         Component cropModule = (Component) paddockModule.LinkByName( crop );

         //Console.WriteLine("3. " + cropModule.Name);
         string plantStatus = "";
         cropModule.Get("plant_status", out plantStatus);

         double esw = 0.0;
         Component soilModule = (Component) paddockModule.LinkByType("SoilWat");
         soilModule.Get("esw", out esw);
         if (plantStatus == "out" &amp;&amp;
             inWindow &amp;&amp;
             rainTracker.Sum() &gt;= rain_amount &amp;&amp;
             esw &gt; esw_amount) 
         {
             isPossibleToday = true;
         } 

	     if (isPossibleToday)
            return 1;
         
         if (plantStatus == "out" &amp;&amp; endOfWindow &amp;&amp; must_sow == "yes")
            return 1;

         if (plantStatus == "out" &amp;&amp; !inWindow)
            return -1;
         
         return 0;
      }
   }  
   
   
   // Sow a crop
   [Param()] private string cultivar1;
   [Param()] private string cultivar2;
   [Param()] private double density1;
   [Param()] private double depth1;
   [Param()] private double row_spacing1;
   [Param()] private string ftn1;
   [Param()] private string skiprow1;
   [Param()] private string tillageImplement;
   
   [EventHandler, Description("Sow the crop")] public void OnEnter()
   {
      Console.WriteLine(today + " Sowing Crop");
      SowType data = new SowType();
      data.Cultivar = cultivar1;
      if(ChangeCultivar)
         data.Cultivar = cultivar2;

      data.plants = density1;
      data.sowing_depth = depth1;
      data.row_spacing = row_spacing1;
      data.tiller_no_fertile = (ftn1 == "na") ? "" : ftn1;
      data.SkipRow = 0 ;
      if (skiprow1 == "single")
         data.SkipRow = 1;
      else if (skiprow1 == "double")
         data.SkipRow = 2;

      string currentPaddock;
      MySimulation.Get("currentPaddock", out currentPaddock);
      Component cropModule;
      if (currentPaddock != "")
         cropModule = (Component) MySimulation.LinkByName(currentPaddock + "." + crop);
      else 
         cropModule = (Component) MySimulation.ChildPaddocks[0].LinkByName(crop);

      cropModule.Publish("Sow", data);

      if (tillageImplement.ToLower() != "na") 
	  {
         TillageType t = new TillageType();
         t.type = tillageImplement;
         Component paddockModule;
         if (currentPaddock != "")
            paddockModule = (Component) MySimulation.LinkByName(currentPaddock);
         else
            paddockModule = MySimulation.ChildPaddocks[0];
         paddockModule.Publish("tillage", t);
      }		 
   }

   // Test whether we can harvest a crop today
   // +ve number - yes
   // 0          - no
   // -ve        - out of scope
   [Output] public int canLeave  
   {
      get 
      {
         string currentPaddock;
         MySimulation.Get("currentPaddock", out currentPaddock);

         string plantStatus = "";
         MySimulation.Get((currentPaddock != "" ? currentPaddock + "." : "") + crop + ".plant_status", out plantStatus);
         if (plantStatus == "out")
            return -1;

         string StageName = "";
         MySimulation.Get((currentPaddock != "" ? currentPaddock + "." : "") + crop + ".StageName", out StageName);
         if (StageName == "harvest_ripe" || plantStatus == "dead")
            return 1;
         return 0;
      }
   }

   [EventHandler] public void OnLeave()
   {
      Console.WriteLine(today + " Harvesting Crop");
      HarvestType hdata = new HarvestType();
      hdata.Remove = 0.0;
      string currentPaddock;
      MySimulation.Get("currentPaddock", out currentPaddock);
      Component cropModule;
      if (currentPaddock != "")
         cropModule = (Component) MySimulation.LinkByName(currentPaddock + "." + crop);
      else 
         cropModule = (Component) MySimulation.ChildPaddocks[0].LinkByName(crop);

      cropModule.Publish("harvest", hdata);

      KillCropType kdata = new KillCropType();
      kdata.KillFraction = 0.0F;
      cropModule.Publish("killcrop", kdata);
      cropModule.Publish("end_crop");
   } 
}
       </text>
        </manager2>
        <manager2 name="Fertilise at Sowing">
          <ui>
            <tag type="category" description="When should fertiliser be applied" />
            <ModuleName type="modulename" description="On which module should the event come from: ">wheat</ModuleName>
            <EventName type="text" description="On which event should spraying be triggered">sowing</EventName>
            <tag type="category" description="Event details" />
            <fertType type="text" description="The type of fertiliser">urea_N</fertType>
            <fertAmt type="text" description="Amount of fertiliser to apply (kg/ha)">150</fertAmt>
          </ui>
          <text>using System;
using System.Linq;
using System.Collections.Generic;
using ModelFramework;

// Crop management: fertilise at sowing
// Multi-paddock aware.
// This component DOES NOT require a trigger from the sequencer.

public class Script 
{      
   [Link]  public Simulation MySimulation;
   [Param] string fertType;
   [Param] float fertAmt;
   [Param] string ModuleName;
   [Param] string EventName;
   
   [EventHandler] public void OnStart_Simulation()
   {
      foreach (Paddock paddock in MySimulation.ChildPaddocks) 
      {
         foreach (Component child in paddock.Children) {
            if(child.Name == ModuleName){
               RuntimeEventHandler.NullFunction curried = () =&gt; OnTrigger(paddock.Name);
               MySimulation.Subscribe(child.FullName + "." + EventName, curried);
               //Console.WriteLine("Subscribed '" + child.FullName + "." + EventName + " =&gt; " + paddock.Name + "'"); 
            }
         }
      }
   }

   public void OnTrigger(string paddock)
   {
      Console.WriteLine("Fertiliser OnTrigger called, paddock='" + paddock + "'"); 
      if (fertAmt &gt; 0) 
      {         
         Component paddockModule;
         if (paddock != "")
            paddockModule = (Component) MySimulation.LinkByName(paddock);
         else
            paddockModule = (Component) MySimulation.ChildPaddocks[0];
         //Console.WriteLine("2. " + paddockModule.Name);

         Fertiliser fertModule = (Fertiliser) paddockModule.LinkByName("Fertiliser");
         fertModule.Apply(fertAmt, 50, fertType);
      }
   }
}
       </text>
        </manager2>
        <operations name="Operations Schedule">
          <operation condition="start_of_day">
            <date>19/7/1987</date>
            <action>wheat end_crop</action>
          </operation>
        </operations>
        <tracker>
          <variable>sum of dly_therm_time on end_day from sowing to harvesting as tt_sum</variable>
          <variable>sum of rain on end_day from harvesting to sowing as fallowrain</variable>
          <variable>sum of rain on end_day from sowing to harvesting as incroprain</variable>
          <variable>sum of irrigation on end_day from sowing to harvesting as incropirrigation</variable>
          <variable>sum of irrigation on end_day from harvesting to sowing as fallowirrigation</variable>
          <variable>sum of es on end_day from sowing to harvesting as incropevaporation</variable>
          <variable>sum of es on end_day from harvesting to sowing as fallowevaporation</variable>
          <variable>sum of eo on end_day from sowing to harvesting as incropeo</variable>
          <variable>sum of eo on end_day from harvesting to sowing as falloweo</variable>
          <variable>sum of drain on end_day from sowing to harvesting as Incropdrain</variable>
          <variable>sum of drain on end_day from harvesting to sowing as fallowdrain</variable>
          <variable>sum of runoff on end_day from sowing to harvesting as Incroprunoff</variable>
          <variable>sum of runoff on end_day from harvesting to sowing as fallowrunoff</variable>
          <variable>sum of evap_tot on end_day from sowing to harvesting as incropet</variable>
          <variable>sum of evap_tot on end_day from harvesting to sowing as fallowet</variable>
          <variable>sum of trw on end_day from sowing to harvesting as incroptrans</variable>
          <variable>sum of rain on end_of_day from start_year to end_year as yearrain</variable>
          <variable>sum of eos on end_day from sowing to harvesting as incropeos</variable>
          <variable>sum of eos on end_day from harvesting to sowing as falloweos</variable>
          <variable>sum of evap_soil on end_day from sowing to harvesting as incropsoilevap</variable>
          <variable>sum of leach_cl on end_day from harvesting to sowing as fallowleachcl</variable>
          <variable>sum of leach_cl on end_day from sowing to harvesting as incropleachcl</variable>
          <variable>sum of leach_no3 on end_day from harvesting to sowing as fallowleachno3</variable>
          <variable>sum of leach_no3 on end_day from sowing to harvesting as incropleachno3</variable>
          <variable>average of maxt on end_day from sowing to harvesting as incropmaxt</variable>
          <variable>average of mint on end_day from sowing to harvesting as incropmint</variable>
          <variable>average of maxt on end_day from harvesting to sowing as fallowmaxt</variable>
          <variable>average of mint on end_day from harvesting to sowing as fallowmint</variable>
          <variable>sum of fertiliser on end_day from sowing to harvesting as incropfertiliser</variable>
          <variable>sum of fertiliser on end_day from harvesting to sowing as fallowfertiliser</variable>
          <variable>sum of n_loss on end_day from sowing to harvesting as incropnloss</variable>
          <variable>sum of n_loss on end_day from harvesting to sowing as fallownloss</variable>
          <variable>sum of erosion on end_day from sowing to harvesting as incroperosion</variable>
          <variable>sum of erosion on end_day from harvesting to sowing as fallowerosion</variable>
          <variable>sum of soil_loss on end_day from sowing to harvesting as incropsoil_loss</variable>
          <variable>sum of soil_loss on end_day from harvesting to sowing as fallowsoil_loss</variable>
          <variable>sum of dnit() on end_day from sowing to harvesting as incropdnit</variable>
          <variable>sum of dnit() on end_day from harvesting to sowing as fallowdnit</variable>
          <variable>sum of n2o_atm() on end_day from sowing to harvesting as incropn2o_atm</variable>
          <variable>sum of n2o_atm() on end_day from harvesting to sowing as fallown2o_atm</variable>
          <variable>sum of ep on end_day from sowing to harvesting as incroptranspiration</variable>
        </tracker>
      </folder>
      <outputfile>
        <filename output="yes">Wheat_greenmount.out</filename>
        <title>Wheat_greenmount</title>
        <variables name="Variables">
          <variable>dd/mm/yyyy as Date</variable>
          <variable>rain</variable>
          <variable>runoff</variable>
          <variable>es</variable>
          <variable>ep</variable>
          <variable>DaysAfteremergence</variable>
        </variables>
        <events name="Reporting Frequency">
          <event>daily</event>
        </events>
      </outputfile>
      <Soil name="Black_Earth_Greenmount">
        <RecordNumber>0</RecordNumber>
        <ASCOrder>Generic</ASCOrder>
        <ASCSubOrder>Generic</ASCSubOrder>
        <SoilType>Generic</SoilType>
        <Site>Generic</Site>
        <NearestTown>Generic</NearestTown>
        <Region>Generic</Region>
        <State>Queensland</State>
        <Country>Australia</Country>
        <NaturalVegetation>Unknown</NaturalVegetation>
        <ApsoilNumber>0</ApsoilNumber>
        <Latitude>-0</Latitude>
        <Longitude>0</Longitude>
        <LocationAccuracy> +/- 20m</LocationAccuracy>
        <YearOfSampling>0</YearOfSampling>
        <DataSource>P2R, DNRM, Toowoomba</DataSource>
        <Comments>Soil naming structure: \State\Region\Classification-Local Name (Site/district and locator number); oc and ph estimated</Comments>
        <Water>
          <Thickness>
            <double>100</double>
            <double>200</double>
            <double>600</double>
            <double>300</double>
            <double>300</double>
            <double>100</double>
          </Thickness>
          <BD>
            <double>1.1</double>
            <double>1.1</double>
            <double>1.2</double>
            <double>1.2</double>
            <double>1.3</double>
            <double>1.3</double>
          </BD>
          <AirDry>
            <double>0.14</double>
            <double>0.248</double>
            <double>0.31</double>
            <double>0.31</double>
            <double>0.31</double>
            <double>0.31</double>
          </AirDry>
          <LL15>
            <double>0.28</double>
            <double>0.31</double>
            <double>0.31</double>
            <double>0.31</double>
            <double>0.31</double>
            <double>0.31</double>
          </LL15>
          <DUL>
            <double>0.46</double>
            <double>0.51</double>
            <double>0.49</double>
            <double>0.47</double>
            <double>0.46</double>
            <double>0.46</double>
          </DUL>
          <SAT>
            <double>0.59</double>
            <double>0.56</double>
            <double>0.54</double>
            <double>0.52</double>
            <double>0.51</double>
            <double>0.51</double>
          </SAT>
          <SoilCrop name="bambatsi">
            <Thickness>
              <double>100</double>
              <double>200</double>
              <double>600</double>
              <double>300</double>
              <double>300</double>
              <double>100</double>
            </Thickness>
            <LL>
              <double>0.28</double>
              <double>0.31</double>
              <double>0.31</double>
              <double>0.31</double>
              <double>0.31</double>
              <double>0.31</double>
            </LL>
            <KL>
              <double>0.06</double>
              <double>0.06</double>
              <double>0.06</double>
              <double>0.04</double>
              <double>0.04</double>
              <double>0.02</double>
            </KL>
            <XF>
              <double>1</double>
              <double>1</double>
              <double>1</double>
              <double>1</double>
              <double>1</double>
              <double>1</double>
            </XF>
          </SoilCrop>
          <SoilCrop name="wheat">
            <Thickness>
              <double>100</double>
              <double>200</double>
              <double>600</double>
              <double>300</double>
              <double>300</double>
              <double>100</double>
            </Thickness>
            <LL>
              <double>0.28</double>
              <double>0.31</double>
              <double>0.31</double>
              <double>0.31</double>
              <double>0.31</double>
              <double>0.31</double>
            </LL>
            <KL>
              <double>0.06</double>
              <double>0.06</double>
              <double>0.06</double>
              <double>0.04</double>
              <double>0.04</double>
              <double>0.02</double>
            </KL>
            <XF>
              <double>1</double>
              <double>1</double>
              <double>1</double>
              <double>1</double>
              <double>1</double>
              <double>1</double>
            </XF>
          </SoilCrop>
        </Water>
        <SoilWater>
          <SummerCona>3</SummerCona>
          <SummerU>5</SummerU>
          <SummerDate>1-Nov</SummerDate>
          <WinterCona>3</WinterCona>
          <WinterU>5</WinterU>
          <WinterDate>1-Apr</WinterDate>
          <DiffusConst>40</DiffusConst>
          <DiffusSlope>16</DiffusSlope>
          <Salb>0.12</Salb>
          <CN2Bare>@ CN2Bare   @</CN2Bare>
          <CNRed>20</CNRed>
          <CNCov>0.8</CNCov>
          <Slope>7</Slope>
          <DischargeWidth>NaN</DischargeWidth>
          <CatchmentArea>NaN</CatchmentArea>
          <MaxPond>NaN</MaxPond>
          <Thickness>
            <double>100</double>
            <double>200</double>
            <double>600</double>
            <double>300</double>
            <double>300</double>
            <double>100</double>
          </Thickness>
          <SWCON>
            <double>0.3</double>
            <double>0.3</double>
            <double>0.3</double>
            <double>0.3</double>
            <double>0.3</double>
            <double>0.3</double>
          </SWCON>
        </SoilWater>
        <SoilOrganicMatter>
          <RootCN>40</RootCN>
          <RootWt>200</RootWt>
          <SoilCN>12.5</SoilCN>
          <EnrACoeff>7.4</EnrACoeff>
          <EnrBCoeff>0.2</EnrBCoeff>
          <Thickness>
            <double>100</double>
            <double>200</double>
            <double>600</double>
            <double>300</double>
            <double>300</double>
            <double>100</double>
          </Thickness>
          <OC>
            <double>1.8</double>
            <double>0.92</double>
            <double>0.84</double>
            <double>0.9</double>
            <double>0.9</double>
            <double>0.94</double>
          </OC>
          <FBiom>
            <double>0.025</double>
            <double>0.025</double>
            <double>0.025</double>
            <double>0.025</double>
            <double>0.025</double>
            <double>0.025</double>
          </FBiom>
          <FInert>
            <double>0.4</double>
            <double>0.4</double>
            <double>0.4</double>
            <double>0.4</double>
            <double>0.4</double>
            <double>0.4</double>
          </FInert>
          <OCUnits>Total</OCUnits>
        </SoilOrganicMatter>
        <InitialWater>
          <FractionFull>0.8</FractionFull>
          <DepthWetSoil>NaN</DepthWetSoil>
          <PercentMethod>FilledFromTop</PercentMethod>
          <RelativeTo>ll15</RelativeTo>
        </InitialWater>
        <Analysis>
          <Thickness>
            <double>100</double>
            <double>200</double>
            <double>600</double>
            <double>300</double>
            <double>300</double>
            <double>100</double>
          </Thickness>
          <Texture>
            <string />
            <string />
            <string />
            <string />
            <string />
            <string />
          </Texture>
          <MunsellColour>
            <string />
            <string />
            <string />
            <string />
            <string />
            <string />
          </MunsellColour>
          <PH>
            <double>7.4</double>
            <double>6</double>
            <double>6</double>
            <double>6</double>
            <double>6</double>
            <double>6</double>
          </PH>
          <PHMetadata>
            <string>Estimated based on local knowledge</string>
            <string>Estimated based on local knowledge</string>
            <string>Estimated based on local knowledge</string>
            <string>Estimated based on local knowledge</string>
            <string>Estimated based on local knowledge</string>
            <string>Estimated based on local knowledge</string>
          </PHMetadata>
          <PHUnits>Water</PHUnits>
          <BoronUnits>HotWater</BoronUnits>
        </Analysis>
        <Sample name="Initial nitrogen">
          <Thickness>
            <double>100</double>
            <double>200</double>
            <double>600</double>
            <double>300</double>
            <double>300</double>
            <double>100</double>
          </Thickness>
          <NO3>
            <double>10</double>
            <double>10</double>
            <double>10</double>
            <double>10</double>
            <double>10</double>
            <double>10</double>
          </NO3>
          <NH4>
            <double>1</double>
            <double>1</double>
            <double>1</double>
            <double>1</double>
            <double>1</double>
            <double>1</double>
          </NH4>
          <NO3Units>ppm</NO3Units>
          <NH4Units>ppm</NH4Units>
          <SWUnits>Volumetric</SWUnits>
          <OCUnits>Total</OCUnits>
          <PHUnits>Water</PHUnits>
        </Sample>
      </Soil>
      <RLink name="Stats">
        <script>
          <text>
# Script to overwrite the standard apsim file (Wheat_greenmount.out) with merged observed data

#  data from http://howleaky.net/images/greenmount%20min%20till.txt
obs&lt;- read.csv("greenmount min till.txt", skip=27, header=T)
obs$Date&lt;-as.Date(obs$Date, format="%d/%m/%Y")
obs$runoff &lt;- obs$Runoff_mm_ZT

trim &lt;- function (x) gsub("^\\s+|\\s+$", "", x)
read.apsim &lt;- function (filename) {
  fp &lt;- file(filename, "r")
  on.exit(close(fp))
  hdr&lt;-readLines(fp, n=4)
  names&lt;-unlist(strsplit(trim(hdr[3]), " +"))
  return(read.table(fp, skip = 0, col.names=names, row.names=NULL, na.strings=c("*", "?")))
}

pred&lt;- read.apsim("Wheat_greenmount.out")
pred$Date&lt;-as.Date(pred$Date, format="%d/%m/%Y")

df&lt;-merge(pred[,c("Date", "runoff")], 
             obs[,c("Date", "runoff")], 
             by="Date", suffixes = c(".pred",".obs"),  all.x = T)
df$month&lt;- as.numeric(format.Date(df$Date, "%m"))
df$year&lt;- as.numeric(format.Date(df$Date, "%Y"))
df$waterYear&lt;-ifelse(df$month &gt;= 11, df$year + 1, df$year)
   
df2&lt;-aggregate(df[,c("runoff.pred" , "runoff.obs")], 
                    list(df$waterYear), sum, na.rm=T)

write.table(df2[df2$runoff.obs &gt; 0,], "Wheat_greenmount.out", row.names=F)
</text>
          <event>end_simulation</event>
        </script>
      </RLink>
    </area>
  </simulation>
</folder>
